# TODO

1. make plan creation easier
1. add image of plans to examples in Trident
1. plan validation before submission (route from Aquarium?)
1. document creating samples with properties
1. document making associations, getting associations, associating
files, downloading files